eol property
The end of line character which is expected after "row".
The eol is optional for the last row.
Implementation
final String? eol;
The end of line character which is expected after "row".
The eol is optional for the last row.
final String? eol;