GitUtil class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkHasBranch(
String pathRep, String branch, {bool onlyRemote = true}) → Future< bool> - 判断是否有当前指定分支
-
checkHasChange(
String pathRep) → Future< bool> - 检测是否含有变动
-
cloneRepository(
String url, String pathRep, {String branch = 'master'}) → Future< void> - 克隆Git仓库到指定位置
-
formatStrFromCli(
String str) → String - 格式化来自命令行的字符 - 移除双引号以及空白符
-
getCurrentBranch(
String pathRep) → Future< String> - 获取当前分支
-
getRemoteBranchList(
String pathRep) → Future< List< String> > - 获取当前仓库包含的远程分支列表
-
getRepositoryPath(
String pathRepo) → String - 基于现有仓库地址,获取正确可用的仓库地址
-
parseBranchesInString(
String stdout) → Iterable< String> - 从字符串中解析分支
-
stashChanges(
String pathRep) → Future< void> - 默认暂存所有文件并拉取对应分支代码
Constants
- kBranchMain → const String
- kBranchMaster → const String
- kHead → const String