TextUtilVersion class

版本号文本处理函数

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatVersionStr(String versionStr) String
格式化版本号字符
isLower(String? versionCurrent, String? versionTarget) bool
判断当前版本是否小于默认指定版本