ValidatorUtilString class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

empty(String? val, {String? tipText}) String?
空白字符校验
isNull<T>(T? val, {String? tipText}) String?
为空判断
mergeValidators(List<StringCallback> validators) String?
合并的校验方法