GetSize class

Constructors

GetSize(BuildContext context, {double? widthRecommend, double? widthLimitRatio, double? widthCurrent, double? heightRecommend, double? heightLimitRatio, double? heightCurrent})

Properties

context BuildContext
final
hashCode int
The hash code for this object.
no setterinherited
height GetSizeSingle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Size
no setter
width GetSizeSingle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited