TextHighlight class

Inheritance

Constructors

TextHighlight(String text, {Key? key, TextStyle? style, TextStyle? highlightStyle, String? highlightText, bool caseSensitive = false})
const

Properties

caseSensitive bool
Whether the search is case sensitive.
final
hashCode int
The hash code for this object.
no setterinherited
highlightStyle TextStyle?
The style to apply to the highlighted text.
final
highlightText String?
The text to highlight.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
The style to apply to the text.
final
text String
The text to display.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getTextSpanList(String text, {String? highlightText, TextStyle? style, TextStyle? highlightStyle, bool caseSensitive = false}) List<TextSpan>
text 输入的搜索内容 highlightText 需要高亮的文字内容 style 默认文本样式 highlightStyle 高亮文本样式 caseSensitive 是否区分大小写