NumberUtil class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatDigitalMillimeter(
num? num, {int point = 2, String nullText = '0'}) → String - 数字千分位格式化
-
formatZero(
num number, {bool isMillimeter = false, int fractionDigits = 2}) → String - 工具方法-去除double类型后面的.0值并返回字符
-
getPercentage(
num? number, num? total, {bool toString = true, bool toDouble = false, bool toInt = false, int point = 2}) → dynamic - 获取百分比