PlatformName class
非Web模式下判断
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- android → String
-
no setter
-
desktop
↔ List<
String> -
getter/setter pair
- fuchsia → String
-
no setter
- ios → String
-
no setter
- isDesktop → bool
-
no setter
- isMobile → bool
-
no setter
- linux → String
-
no setter
- macos → String
-
no setter
-
mobile
↔ List<
String> -
getter/setter pair
- name → String?
-
no setter
-
values
→ List<
String> -
no setter
- web → String
-
no setter
- windows → String
-
no setter