ProcessUtil class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
runCmd({String? cmd, ProcessRunner? runner, String? workingDirectory, bool runInShell = true, ProcessStartMode mode = ProcessStartMode.inheritStdio, bool waitForExit = true, Map<String, String>? environment})
→ Future<Process>
-
执行指令
-
runCmdWait({String? cmd, ProcessRunner? runner, String? workingDirectory, bool runInShell = true, Map<String, String>? environment})
→ Future<ProcessResult>
-
运行指令并等待执行完成
-
runCmdWaitSync({String? cmd, ProcessRunner? runner, String? workingDirectory, bool runInShell = true, Map<String, String>? environment})
→ ProcessResult
-
同步运行指令并等待指令完成