SentryUtil class
公共日志上传工具
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
init(
{required String dsn, AppRunner? runner, bool enable = true, BeforeSendCallback? beforeSendCallback}) → Future< void> - 初始化
-
reportError(
dynamic error, dynamic stackTrace, {bool toast = true}) → Future< void> - 手动上报日志
-
reportHttpError(
dynamic err, dynamic request, {bool toast = true}) → Future< void> - 上报Http请求错误信息