Refresh<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- Refresh
Constructors
-
Refresh({Key? key, required GetPaginationData<
T> fetchData, required ItemBuilder<T> itemBuilder, Pagination<T> ? initialValue, bool enableLoad = true, bool enableRefresh = true, EasyRefreshController? controller, bool canRefreshAfterNoMore = false, bool canLoadAfterNoMore = false, double callLoadOverOffset = 20, double callRefreshOverOffset = 20, bool refreshOnStart = true, Header? header, Key? listKey, Axis scrollDirection = Axis.vertical, bool reverse = false, ScrollController? scrollController, bool shrinkWrap = false, DragStartBehavior dragStartBehavior = DragStartBehavior.start, Widget? emptyWidget, EdgeInsetsGeometry? padding, ValueChanged<Pagination< ? onFetched})T> > -
const
Properties
- callLoadOverOffset → double
-
Offset beyond trigger offset when calling load.
Used when EasyRefreshController.callLoad.
final
- callRefreshOverOffset → double
-
Offset beyond trigger offset when calling refresh.
Used when refreshOnStart is true and EasyRefreshController.callRefresh.
final
- canLoadAfterNoMore → bool
-
Is it possible to load after there is no more.
final
- canRefreshAfterNoMore → bool
-
Is it possible to refresh after there is no more.
final
- controller → EasyRefreshController?
-
刷新控制器
final
- dragStartBehavior → DragStartBehavior
-
列表渲染视图属性
final
- emptyWidget → Widget?
-
数据为空时视图
final
- enableLoad → bool
-
是否启用上拉更多
final
- enableRefresh → bool
-
是否启用下拉刷新
final
-
fetchData
→ GetPaginationData<
T> -
获取数据方法
final
-
Footer
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Header?
-
Header
final
-
initialValue
→ Pagination<
T> ? -
初始值
final
-
itemBuilder
→ ItemBuilder<
T> -
视图构建器
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listKey → Key?
-
CustomListView Key
final
-
onFetched
→ ValueChanged<
Pagination< ?T> > -
数据值改变回调(默认数据请求返回后执行回调)
final
- padding → EdgeInsetsGeometry?
-
内边距
final
- refreshOnStart → bool
-
首次刷新
final
- reverse → bool
-
列表渲染视图属性 - 反向
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
列表渲染视图属性
final
- scrollDirection → Axis
-
列表方向
final
- shrinkWrap → bool
-
列表渲染视图属性
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → RefreshState< T> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited